Module helpers

Module helpers 

Functions

extract_file_ext
Extract a file extension (without period) from the provided file path or URL.
extract_file_name
Extract a file name from the provided file path or URL.
is_file_like
Returns true if the value looks like a file, by checking for file://, path separators, or supported file extensions.
is_secure_url
Returns true if the value is a secure URL, by checking for https://. This check can be bypassed for localhost URLs.
is_url_like
Returns true if the value looks like a URL, by checking for http://, https://, or www.
strip_bom
Strip a leading BOM from the string.