pub struct Schema {
pub deprecated: Option<String>,
pub description: Option<String>,
pub name: Option<String>,
pub nullable: bool,
pub ty: SchemaType,
}Expand description
Describes the metadata and shape of a type.
Fields
deprecated: Option<String>description: Option<String>name: Option<String>nullable: boolty: SchemaTypeImplementations
Sourceimpl Schema
impl Schema
Sourcepub fn new(ty: impl Into<SchemaType>) -> Schema
pub fn new(ty: impl Into<SchemaType>) -> Schema
Create a schema with the provided type.
Sourcepub fn boolean(value: BooleanType) -> Schema
pub fn boolean(value: BooleanType) -> Schema
Create a boolean schema.
Sourcepub fn enumerable(value: EnumType) -> Schema
pub fn enumerable(value: EnumType) -> Schema
Create an enum schema.
Sourcepub fn integer(value: IntegerType) -> Schema
pub fn integer(value: IntegerType) -> Schema
Create an integer schema.
Sourcepub fn literal(value: LiteralType) -> Schema
pub fn literal(value: LiteralType) -> Schema
Create a literal schema.
Sourcepub fn literal_value(value: LiteralValue) -> Schema
pub fn literal_value(value: LiteralValue) -> Schema
Create a literal schema with the provided value.
Sourcepub fn object(value: ObjectType) -> Schema
pub fn object(value: ObjectType) -> Schema
Create an object schema.
Sourcepub fn reference(name: impl AsRef<str>) -> Schema
pub fn reference(name: impl AsRef<str>) -> Schema
Create a schema that references another schema by name.
Sourcepub fn string(value: StringType) -> Schema
pub fn string(value: StringType) -> Schema
Create a string schema.
Sourcepub fn structure(value: StructType) -> Schema
pub fn structure(value: StructType) -> Schema
Create a struct schema.
Sourcepub fn nullify(&mut self)
pub fn nullify(&mut self)
Convert the current schema to a nullable type. If already nullable, do nothing, otherwise convert to a union.
Sourcepub fn partialize(&mut self)
pub fn partialize(&mut self)
Mark the inner schema type as partial. Only structs, unions, and references can be marked partial, but arrays, objects, and tuples will also be recursively set to update the inner types.
Sourcepub fn set_deprecated(&mut self, value: impl AsRef<str>)
pub fn set_deprecated(&mut self, value: impl AsRef<str>)
Mark this schema as deprecated.
Sourcepub fn set_description(&mut self, value: impl AsRef<str>)
pub fn set_description(&mut self, value: impl AsRef<str>)
Add a description for this schema.
Sourcepub fn set_type(&mut self, value: SchemaType)
pub fn set_type(&mut self, value: SchemaType)
Set the type of schema.
Sourcepub fn get_default(&self) -> Option<&LiteralValue>
pub fn get_default(&self) -> Option<&LiteralValue>
Return a default value from the inner schema type.
Sourcepub fn set_default(&mut self, default: LiteralValue) -> bool
pub fn set_default(&mut self, default: LiteralValue) -> bool
Set the default of the inner schema type. Returns false when the
type holds no default.
Sourcepub fn add_field(&mut self, key: &str, value: impl Into<SchemaField>) -> bool
pub fn add_field(&mut self, key: &str, value: impl Into<SchemaField>) -> bool
Add a field to the inner type if it’s a struct. Returns false when it isn’t one.
Sourcepub fn is_nullable(&self) -> bool
pub fn is_nullable(&self) -> bool
Return true if the inner type is nullable (a union with a null).
Sourcepub fn is_reference(&self) -> bool
pub fn is_reference(&self) -> bool
Return true if the inner type is a reference.
Sourcepub fn get_nonnull_schema(&self) -> Option<&Schema>
pub fn get_nonnull_schema(&self) -> Option<&Schema>
Return a non-null schema if available. If a null type,
returns None. If a union type, returns the first variant that
resolves to a non-null type, or None. Otherwise, returns the
current type.